@@ -1,9 +1,9 @@
 package HTTP::Throwable;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::VERSION = '0.020';
-use Moose::Role;
-use MooseX::StrictConstructor;
-use MooseX::Role::WithOverloading 0.09;
+$HTTP::Throwable::VERSION = '0.022';
+use Types::Standard qw(Int Str ArrayRef);
+
+use Moo::Role;
 
 use overload
     '&{}' => 'to_app',
@@ -16,25 +16,25 @@ with 'Throwable';
 
 has 'status_code' => (
     is       => 'ro',
-    isa      => 'Int',
+    isa      => Int,
     builder  => 'default_status_code',
 );
 
 has 'reason' => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
     builder  => 'default_reason',
 );
 
 has 'message' => (
     is  => 'ro',
-    isa => 'Str',
+    isa => Str,
     predicate => 'has_message',
 );
 
 # TODO: type this attribute more strongly -- rjbs, 2011-02-21
-has 'additional_headers' => ( is => 'ro', isa => 'ArrayRef' );
+has 'additional_headers' => ( is => 'ro', isa => ArrayRef );
 
 sub build_headers {
     my ($self, $body) = @_;
@@ -89,7 +89,7 @@ sub is_server_error {
     return $status >= 500 && $status < 600;
 }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -101,7 +101,7 @@ HTTP::Throwable - a set of strongly-typed, PSGI-friendly HTTP 1.1 exception libr
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -416,7 +416,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Brian Cassidy Karen Etheridge
+=for stopwords Brian Cassidy Fitz Elliott Karen Etheridge
 
 =over 4
 
@@ -426,6 +426,10 @@ Brian Cassidy <bricas@cpan.org>
 
 =item *
 
+Fitz Elliott <felliott@fiskur.org>
+
+=item *
+
 Karen Etheridge <ether@cpan.org>
 
 =back
