@@ -1,12 +1,11 @@
 package HTTP::Throwable::Role::BoringText;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::BoringText::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::BoringText::VERSION = '0.022';
+use Moo::Role;
 
 sub text_body { $_[0]->status_line }
 
-no Moose::Role;
-1;
+no Moo::Role; 1;
 
 =pod
 
@@ -18,7 +17,7 @@ HTTP::Throwable::Role::BoringText - provide the simplest text_body method possib
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 OVERVIEW
 
