@@ -1,7 +1,9 @@
 package HTTP::Throwable::Role::Generic;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Generic::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Generic::VERSION = '0.022';
+use Carp qw(confess);
+
+use Moo::Role;
 
 with 'HTTP::Throwable';
 
@@ -13,7 +15,7 @@ sub default_reason {
     confess "generic HTTP::Throwable must be given reason in constructor";
 }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -25,7 +27,7 @@ HTTP::Throwable::Role::Generic - a generic built-by-hand exception
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
