@@ -1,7 +1,7 @@
 package HTTP::Throwable::Role::NoBody;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::NoBody::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::NoBody::VERSION = '0.022';
+use Moo::Role;
 
 sub body { return }
 
@@ -15,8 +15,7 @@ sub body_headers {
 
 sub as_string { $_[0]->status_line }
 
-no Moose::Role;
-1;
+no Moo::Role; 1;
 
 =pod
 
@@ -28,7 +27,7 @@ HTTP::Throwable::Role::NoBody - an exception with no body
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 OVERVIEW
 
