@@ -1,11 +1,13 @@
 package HTTP::Throwable::Role::Redirect;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Redirect::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Redirect::VERSION = '0.022';
+use Types::Standard qw(Str);
+
+use Moo::Role;
 
 has 'location' => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
@@ -18,7 +20,7 @@ around 'build_headers' => sub {
     return $headers;
 };
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -30,7 +32,7 @@ HTTP::Throwable::Role::Redirect - an exception that is a redirect
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 OVERVIEW
 
