@@ -1,7 +1,7 @@
 package HTTP::Throwable::Role::Status::BadRequest;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::BadRequest::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Status::BadRequest::VERSION = '0.022';
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -12,7 +12,7 @@ sub default_status_code { 400 }
 
 sub default_reason { 'Bad Request' }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -24,7 +24,7 @@ HTTP::Throwable::Role::Status::BadRequest - 400 Bad Request
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
