@@ -1,7 +1,7 @@
 package HTTP::Throwable::Role::Status::Gone;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::Gone::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Status::Gone::VERSION = '0.022';
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -11,7 +11,7 @@ with(
 sub default_status_code { 410 }
 sub default_reason      { 'Gone' }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -23,7 +23,7 @@ HTTP::Throwable::Role::Status::Gone - 410 Gone
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
