@@ -1,14 +1,16 @@
 package HTTP::Throwable::Role::Status::ImATeapot;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::ImATeapot::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Status::ImATeapot::VERSION = '0.022';
+use Types::Standard qw(Bool);
+
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
 );
 
-has 'short' => (is => 'ro', isa => 'Bool', default => 0);
-has 'stout' => (is => 'ro', isa => 'Bool', default => 0);
+has 'short' => (is => 'ro', isa => Bool, default => 0);
+has 'stout' => (is => 'ro', isa => Bool, default => 0);
 
 sub default_status_code { 418 }
 sub default_reason      { q{I'm a teapot} }
@@ -40,7 +42,7 @@ sub text_body {
     return $base;
 }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -52,7 +54,7 @@ HTTP::Throwable::Role::Status::ImATeapot - 418 I'm a teapot
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
