@@ -1,7 +1,9 @@
 package HTTP::Throwable::Role::Status::InternalServerError;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::InternalServerError::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Status::InternalServerError::VERSION = '0.022';
+use Types::Standard qw(Bool);
+
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -11,7 +13,7 @@ with(
 sub default_status_code { 500 }
 sub default_reason      { 'Internal Server Error' }
 
-has 'show_stack_trace' => ( is => 'ro', isa => 'Bool', default => 1 );
+has 'show_stack_trace' => ( is => 'ro', isa => Bool, default => 1 );
 
 sub text_body {
     my ($self) = @_;
@@ -23,7 +25,7 @@ sub text_body {
     return $out;
 }
 
-no Moose; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -35,7 +37,7 @@ HTTP::Throwable::Role::Status::InternalServerError - 500 Internal Server Error
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
