@@ -1,17 +1,18 @@
 package HTTP::Throwable::Role::Status::MethodNotAllowed;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::MethodNotAllowed::VERSION = '0.020';
-use Moose::Role;
-use Moose::Util::TypeConstraints;
-
+$HTTP::Throwable::Role::Status::MethodNotAllowed::VERSION = '0.022';
+use Type::Utils qw(subtype as where enum);
+use Types::Standard qw(ArrayRef);
 use List::AllUtils qw[ uniq ];
 
+use Moo::Role;
+
 with(
     'HTTP::Throwable',
     'HTTP::Throwable::Role::BoringText',
 );
 
-enum 'HTTP::Throwable::Type::Method' => [ qw[
+my $method_enum_type = enum "HttpThrowableTypeMethod" => [ qw[
     OPTIONS GET HEAD
     POST PUT DELETE
     TRACE CONNECT
@@ -19,16 +20,16 @@ enum 'HTTP::Throwable::Type::Method' => [ qw[
 
 # TODO: Consider adding a coersion to upper-case lower-cased strings and to
 # uniq the given input.  -- rjbs, 2011-02-21
-subtype 'HTTP::Throwable::Type::MethodList'
-    => as 'ArrayRef'
-    => where { (scalar uniq @{$_}) == (scalar @{$_}) };
+my $method_list_type = subtype "HttpThrowableTypeMethodList",
+    as ArrayRef[ $method_enum_type ],
+    where { (scalar uniq @{$_}) == (scalar @{$_}) };
 
 sub default_status_code { 405 }
 sub default_reason      { 'Method Not Allowed' }
 
 has 'allow' => (
     is       => 'ro',
-    isa      => 'HTTP::Throwable::Type::MethodList[ HTTP::Throwable::Type::Method ]',
+    isa      => $method_list_type,
     required => 1
 );
 
@@ -40,7 +41,8 @@ around 'build_headers' => sub {
     $headers;
 };
 
-no Moose::Role; no Moose::Util::TypeConstraints; 1;
+
+no Moo::Role; 1;
 
 =pod
 
@@ -52,7 +54,7 @@ HTTP::Throwable::Role::Status::MethodNotAllowed - 405 Method Not Allowed
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
