@@ -1,7 +1,7 @@
 package HTTP::Throwable::Role::Status::NotModified;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::NotModified::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Status::NotModified::VERSION = '0.022';
+use Moo::Role;
 
 use Plack::Util ();
 
@@ -27,7 +27,7 @@ around 'as_psgi' => sub {
     $psgi;
 };
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -39,7 +39,7 @@ HTTP::Throwable::Role::Status::NotModified - 304 Not Modified
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
