@@ -1,7 +1,9 @@
 package HTTP::Throwable::Role::Status::ProxyAuthenticationRequired;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::ProxyAuthenticationRequired::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Status::ProxyAuthenticationRequired::VERSION = '0.022';
+use Types::Standard qw(Str ArrayRef);
+
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -13,7 +15,7 @@ sub default_reason      { 'Proxy Authentication Required' }
 
 has 'proxy_authenticate' => (
     is       => 'ro',
-    isa      => 'Str | ArrayRef[ Str ]',
+    isa      => Str | ArrayRef[ Str ],
     required => 1,
 );
 
@@ -31,7 +33,7 @@ around 'build_headers' => sub {
     $headers;
 };
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -43,7 +45,7 @@ HTTP::Throwable::Role::Status::ProxyAuthenticationRequired - 407 Proxy Authentic
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
