@@ -1,7 +1,9 @@
 package HTTP::Throwable::Role::Status::RequestedRangeNotSatisfiable;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::RequestedRangeNotSatisfiable::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Status::RequestedRangeNotSatisfiable::VERSION = '0.022';
+use Types::Standard qw(Str);
+
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -11,7 +13,7 @@ with(
 sub default_status_code { 416 }
 sub default_reason      { 'Requested Range Not Satisfiable' }
 
-has 'content_range' => ( is => 'ro', isa => 'Str' );
+has 'content_range' => ( is => 'ro', isa => Str );
 
 around 'build_headers' => sub {
     my $next    = shift;
@@ -23,7 +25,7 @@ around 'build_headers' => sub {
     $headers;
 };
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -35,7 +37,7 @@ HTTP::Throwable::Role::Status::RequestedRangeNotSatisfiable - 416 Requested Rang
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
