@@ -1,7 +1,7 @@
 package HTTP::Throwable::Role::Status::SeeOther;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::Status::SeeOther::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::Status::SeeOther::VERSION = '0.022';
+use Moo::Role;
 
 with(
     'HTTP::Throwable',
@@ -12,7 +12,7 @@ with(
 sub default_status_code { 303 }
 sub default_reason      { 'See Other' }
 
-no Moose::Role; 1;
+no Moo::Role; 1;
 
 =pod
 
@@ -24,7 +24,7 @@ HTTP::Throwable::Role::Status::SeeOther - 303 See Other
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 DESCRIPTION
 
