@@ -1,7 +1,7 @@
 package HTTP::Throwable::Role::TextBody;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Role::TextBody::VERSION = '0.020';
-use Moose::Role;
+$HTTP::Throwable::Role::TextBody::VERSION = '0.022';
+use Moo::Role;
 
 sub body { $_[0]->text_body }
 
@@ -18,8 +18,7 @@ sub as_string { $_[0]->body }
 
 requires 'text_body';
 
-no Moose::Role;
-1;
+no Moo::Role; 1;
 
 =pod
 
@@ -31,7 +30,7 @@ HTTP::Throwable::Role::TextBody - an exception with a plaintext body
 
 =head1 VERSION
 
-version 0.020
+version 0.022
 
 =head1 OVERVIEW
 
